#
# spec file for package gedit-plugins
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2009 Dominique Leuenberger, Almere, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gedit-plugins
Version:        48.1
Release:        3.1
Summary:        A collection of plugins for gedit
License:        GPL-2.0-or-later
Group:          Productivity/Text/Editors
URL:            https://wiki.gnome.org/Apps/Gedit/PluginsLists
Source0:        %{name}-%{version}.tar.zst
Source1:        gedit-plugins.SUSE
# PATCH-FIX-UPSTREAM bracketcompletion-use-key-release-event-to-work-wi.patch boo#1027448 bgo#778737 hillwood@opensuse.org -- Switch to use key release event for ibus pinyin input method
Patch0:         bracketcompletion-use-key-release-event-to-work-wi.patch

BuildRequires:  fdupes
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  python3-base
# configure tests for python gi-bindings of gucharmap
BuildRequires:  typelib-1_0-Gucharmap-2_90
BuildRequires:  vala >= 0.28.0
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(appstream-glib)
BuildRequires:  pkgconfig(dbus-python) >= 0.82
BuildRequires:  pkgconfig(gedit) >= 48.1
BuildRequires:  pkgconfig(gio-2.0) >= 2.32.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.9.0
BuildRequires:  pkgconfig(libgit2-glib-1.0) >= 0.0.6
BuildRequires:  pkgconfig(libpeas-1.0) >= 1.7.0
BuildRequires:  pkgconfig(libpeas-gtk-1.0) >= 1.7.0
BuildRequires:  pkgconfig(vte-2.91)
Requires:       gedit >= 48.1
Recommends:     %{name}-data
Suggests:       gedit-plugin-bookmarks
Suggests:       gedit-plugin-bracketcompletion
Suggests:       gedit-plugin-charmap
Suggests:       gedit-plugin-codecomment
Suggests:       gedit-plugin-colorpicker
Suggests:       gedit-plugin-drawspaces
Suggests:       gedit-plugin-joinlines
Suggests:       gedit-plugin-multiedit
Suggests:       gedit-plugin-smartspaces
Suggests:       gedit-plugin-session-saver
Suggests:       gedit-plugin-terminal
Suggests:       gedit-plugin-wordcompletion
Enhances:       gedit
Obsoletes:      gedit-plugin-dashboard <= %{version}
# Zeitgeist plugin was removed with version 3.35.90
Obsoletes:      gedit-plugin-zeitgeist < 3.35.90
# gedit-plugin-colorschemer was removed with version 45.alpha
Obsoletes:      gedit-plugin-colorschemer < 45.alpha
# Synctex plugin was removed with version 45.0
Obsoletes:      gedit-plugin-synctex < 45.0

%description
This package contains a number of plugins for gedit, such as:

 * Bracket Completion: Automatically adds a closing bracket when you
   insert an opening one
 * Charmap: Select characters from a charactermap
 * Code Comment: Comment or uncomment blocks of code
 * Color picker: Select and insert a color from a dialog (for html,
   css, php)
 * Join lines/Split lines: Join or split multiple lines through Ctrl+J
   and Ctrl+Shift+J
 * Session Saver: Allows to bookmark working sessions in order to get
   them back for further use
 * Smart Spaces: Allows to unindent like if you were using tabs while
   you're using spaces
 * Show tabbar: A plugin to show or hide the gedit tabbar
 * Terminal: A terminal widget accessible from the bottom panel

%package -n %{name}-data
Summary:        Common data required by gedit plugins
Group:          Productivity/Text/Editors
Requires:       gedit

%description -n %{name}-data
Common files required by all gedit plugins

%package -n gedit-plugin-bookmarks
Summary:        Gedit bookmarks plugin
Group:          Productivity/Text/Editors
Requires:       %{name}-data = %{version}
Provides:       gedit-plugins:%{_libdir}/gedit/plugins/bookmarks.plugin

%description -n gedit-plugin-bookmarks
The gedit bookmarks plugin.

%package -n gedit-plugin-bracketcompletion
Summary:        Gedit bracketcompletion plugin
Group:          Productivity/Text/Editors
Requires:       %{name}-data = %{version}
Provides:       gedit-plugins:%{_libdir}/gedit/plugins/bracketcompletion.plugin

%description -n gedit-plugin-bracketcompletion
The gedit bracketcompletion plugin.

%package -n gedit-plugin-charmap
Summary:        Gedit charmap plugin
Group:          Productivity/Text/Editors
Requires:       %{name}-data = %{version}
Provides:       gedit-plugins:%{_libdir}/gedit/plugins/charmap.plugin

%description -n gedit-plugin-charmap
The gedit charmap plugin.

%package -n gedit-plugin-codecomment
Summary:        Gedit codecomment plugin
Group:          Productivity/Text/Editors
Requires:       %{name}-data = %{version}
Provides:       gedit-plugins:%{_libdir}/gedit/plugins/codecomment.plugin

%description -n gedit-plugin-codecomment
The gedit codecomment plugin.

%package -n gedit-plugin-colorpicker
Summary:        Gedit colorpicker plugin
Group:          Productivity/Text/Editors
Requires:       %{name}-data = %{version}
Provides:       gedit-plugins:%{_libdir}/gedit/plugins/colorpicker.plugin

%description -n gedit-plugin-colorpicker
The gedit colorpicker plugin.

%package -n gedit-plugin-drawspaces
Summary:        Gedit drawspaces plugin
Group:          Productivity/Text/Editors
Requires:       %{name}-data = %{version}
Provides:       gedit-plugins:%{_libdir}/gedit/plugins/drawspaces.plugin

%description -n gedit-plugin-drawspaces
The gedit drawspaces plugin.

%package -n gedit-plugin-joinlines
Summary:        Gedit joinlines plugin
Group:          Productivity/Text/Editors
Requires:       %{name}-data = %{version}
Provides:       gedit-plugins:%{_libdir}/gedit/plugins/joinlines.plugin

%description -n gedit-plugin-joinlines
The gedit joinlines plugin

%package -n gedit-plugin-multiedit
Summary:        Gedit multiedit plugin
Group:          Productivity/Text/Editors
Requires:       %{name}-data = %{version}
Provides:       gedit-plugins:%{_libdir}/gedit/plugins/multiedit.plugin

%description -n gedit-plugin-multiedit
The gedit multiedit plugin

%package -n gedit-plugin-smartspaces
Summary:        Gedit smartspaces plugin
Group:          Productivity/Text/Editors
Requires:       %{name}-data = %{version}
Provides:       gedit-plugins:%{_libdir}/gedit/plugins/smartspaces.plugin

%description -n gedit-plugin-smartspaces
The gedit smartspaces plugin

%package -n gedit-plugin-session-saver
Summary:        Gedit session-saver plugin
Group:          Productivity/Text/Editors
Requires:       %{name}-data = %{version}
Provides:       gedit-plugins:%{_libdir}/gedit/plugins/session-saver.plugin

%description -n gedit-plugin-session-saver
The gedit session-saver plugin

%package -n gedit-plugin-terminal
Summary:        Gedit terminal plugin
Group:          Productivity/Text/Editors
Requires:       %{name}-data = %{version}
Provides:       gedit-plugins:%{_libdir}/gedit/plugins/terminal.plugin

%description -n gedit-plugin-terminal
The gedit terminal plugin

%package -n gedit-plugin-wordcompletion
Summary:        Gedit wordcompletion plugin
Group:          Productivity/Text/Editors
Requires:       %{name}-data = %{version}
Provides:       gedit-plugins:%{_libdir}/gedit/plugins/wordcompletion.plugin

%description -n gedit-plugin-wordcompletion
The gedit wordcompletion plugin

%lang_package

%prep
%autosetup -p1
install -m644 %{SOURCE1} .

%build
%meson \
    -Dplugin_bracketcompletion=false \
    -Dplugin_charmap=false           \
    -Dplugin_codecomment=false       \
    -Dplugin_colorpicker=false       \
    -Dplugin_joinlines=false         \
    -Dplugin_multiedit=false         \
    -Dplugin_sessionsaver=false      \
    -Dplugin_terminal=false
%meson_build

%install
%meson_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name} %{?no_lang_C}
%find_lang gedit %{name}.lang %{?no_lang_C}
%fdupes %{buildroot}%{_prefix}

%files
%doc gedit-plugins.SUSE
%doc %{_datadir}/help/C/gedit

%files -n %{name}-data
# Common files
%{_libdir}/gedit/plugins/gpdefs.py*

%files -n gedit-plugin-bookmarks
## Explicitly list all plugins so we know when we miss one
# bookmarks
%{_datadir}/metainfo/gedit-bookmarks.metainfo.xml
%{_libdir}/gedit/plugins/bookmarks.plugin
%{_libdir}/gedit/plugins/libbookmarks.so

%dnl %files -n gedit-plugin-bracketcompletion
%dnl # bracketcompletion
%dnl %{_datadir}/metainfo/gedit-bracketcompletion.metainfo.xml
%dnl %{_libdir}/gedit/plugins/bracketcompletion.plugin
%dnl %{_libdir}/gedit/plugins/bracketcompletion.py*

%dnl %files -n gedit-plugin-charmap
%dnl # charmap
%dnl %{_datadir}/metainfo/gedit-charmap.metainfo.xml
%dnl %{_libdir}/gedit/plugins/charmap.plugin
%dnl %{_libdir}/gedit/plugins/charmap/

%dnl %files -n gedit-plugin-codecomment
%dnl # codecomment
%dnl %{_datadir}/metainfo/gedit-codecomment.metainfo.xml
%dnl %{_libdir}/gedit/plugins/codecomment.plugin
%dnl %{_libdir}/gedit/plugins/codecomment.py*

%dnl %files -n gedit-plugin-colorpicker
%dnl # colorpicker
%dnl %{_datadir}/metainfo/gedit-colorpicker.metainfo.xml
%dnl %{_libdir}/gedit/plugins/colorpicker.plugin
%dnl %{_libdir}/gedit/plugins/colorpicker.py*

%files -n gedit-plugin-drawspaces
# drawspaces
%{_datadir}/metainfo/gedit-drawspaces.metainfo.xml
%{_libdir}/gedit/plugins/drawspaces.plugin
%{_libdir}/gedit/plugins/libdrawspaces.so
%{_datadir}/glib-2.0/schemas/org.gnome.gedit.plugins.drawspaces.gschema.xml

%dnl %files -n gedit-plugin-joinlines
%dnl # joinlines
%dnl %{_datadir}/metainfo/gedit-joinlines.metainfo.xml
%dnl %{_libdir}/gedit/plugins/joinlines.plugin
%dnl %{_libdir}/gedit/plugins/joinlines.py*

%dnl %files -n gedit-plugin-multiedit
%dnl # multiedit
%dnl %{_datadir}/metainfo/gedit-multiedit.metainfo.xml
%dnl %{_libdir}/gedit/plugins/multiedit.plugin
%dnl %{_libdir}/gedit/plugins/multiedit/

%files -n gedit-plugin-smartspaces
# smartspaces
%{_datadir}/metainfo/gedit-smartspaces.metainfo.xml
%{_libdir}/gedit/plugins/smartspaces.plugin
%{_libdir}/gedit/plugins/libsmartspaces.so

%dnl %files -n gedit-plugin-session-saver
%dnl # session-saver
%dnl %{_datadir}/gedit/plugins/sessionsaver/
%dnl %{_libdir}/gedit/plugins/sessionsaver.plugin
%dnl %{_libdir}/gedit/plugins/sessionsaver/

%dnl %files -n gedit-plugin-terminal
%dnl # terminal
%dnl %{_datadir}/metainfo/gedit-terminal.metainfo.xml
%dnl %{_libdir}/gedit/plugins/terminal.plugin
%dnl %{_libdir}/gedit/plugins/terminal.py*
%dnl %{_datadir}/glib-2.0/schemas/org.gnome.gedit.plugins.terminal.gschema.xml

%files -n gedit-plugin-wordcompletion
# wordcompletion
%{_datadir}/metainfo/gedit-wordcompletion.metainfo.xml
%{_libdir}/gedit/plugins/wordcompletion.plugin
%{_libdir}/gedit/plugins/libwordcompletion.so
%{_datadir}/glib-2.0/schemas/org.gnome.gedit.plugins.wordcompletion.gschema.xml

%files lang -f %{name}.lang

%changelog
* Mon Mar 31 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Disable python-based plugins, as they are not compatible with the
  GNOME 48 infrastructure, mainly pygobject 3.52. The disabled
  plugins are: bracketcompletion, charmap, codecomment,
  colorpicker, joinlines, multiedit, sessionsaver, and terminal.
  See glgo#World/gedit/gedit#614, boo1239952.
* Fri Mar 14 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Drop pkgconfig(gtksourceview-4) BuildRequires: Not needed nor
  used.
* Sat Dec  7 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.1:
  + Updated translations.
* Wed Oct  2 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 48.0:
  + Port to latest gedit API.
  + Build: some refactorings.
  + Text Size plugin: moved to the main gedit repository.
  + Git plugin: removed.
  + Translation updates.
- Changes from version 47.1:
  + Session Saver plugin: bug fix.
- Changes from version 47.0:
  + Port to latest libgedit-gtksourceview API.
* Wed Apr  3 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0+5:
  + Actually revert to gedit-plugins 46.0: do not rely on the
    so-far unclear 47 API.
* Fri Feb 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0+9:
  + bookmarks: adapt to latest GtkSourceStyle API.
  + sessionsaver: explicit Tepl version req.
* Mon Aug 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 46.0:
  + Port to latest gedit API.
  + Updated translations.
* Fri Jun 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + Remove synctex plugin (see the git commit for the details).
  + Some misc maintenance.
- Drop gedit-plugin-synctex sub-package following upstream changes.
- Drop gedit-plugin-colorschemer sub-package: dropped since
  45.alpha.
* Fri Jan 20 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.1:
  + Some bug fixes.
* Thu Jan  5 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Terminal plugin: check that all external GSettings can be used
    before using them.
  + Updated translations.
* Fri Nov  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.1:
  + Be able to build with Meson >= 0.61
- Changes from version 43.0:
  + Come back to the source code of gedit-plugins a little before
    version 40.0, and continue again from there. It is based on the
    Tepl library.
  + Remove several plugins:
  - translate
  - find in files
  - commander
    Any help to give them a new life would be much welcomed.
  + Updated translations.
- Drop sub-packages:
  + gedit-plugin-commander
  + gedit-plugin-findinfiles
  + gedit-plugin-translate
* Mon May 30 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.1:
  + Updated translations.
* Tue Apr  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.0:
  + Updated translations.
* Wed Feb 16 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + Fix build with latest meson.
  + Updated translations.
- Drop 27.patch: Fixed upstream.
* Wed Feb  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 27.patch: Fix build with meson 0.61.0 and newer.
- Use sed to fix the shebang in some of the plugins.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Fri Apr 30 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.1:
  + Removes tepl dependency.
  + Fixes SessionSaver plugin does not start problem.
  + Updated translations.
* Wed Mar 24 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Draw Spaces plugin: new implementation based on
    TeplSpaceDrawerPrefs.
  + Smart Spaces plugin: Python to C rewrite, new implementation
    based on the GtkSourceView:smart-backspace property.
  + Translate plugin: a few improvements.
  + Updated translations.
* Fri Nov 20 2020 bjorn.lie@gmail.com
- Update to version 3.38.1:
  + Updated translations.
* Fri Sep 11 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Sat Sep  5 2020 dimstar@opensuse.org
- Update to version 3.37.92:
  + Updates to the user manual.
  + Various small improvements.
  + Updated translations.
* Fri Mar 20 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.2:
  + Fix Session Saver plugin.
  + Fix crash in Find in Files plugin.
* Wed Mar 11 2020 bjorn.lie@gmail.com
- Update to version 3.36.1:
  + Embedded terminal plugin: fix crash caused by removed
    gnome-terminal GSettings key.
* Fri Mar  6 2020 bjorn.lie@gmail.com
- Update to version 3.36.0:
  + Updates to the user manual.
  + Updated translations.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + Remove the Zeitgeist plugin.
  + Small code improvements.
- Changes from version 3.35.1:
  + Lots of improvements to the build system (meson).
  + Adapt file metadata key name for gedit 3.35.
  + Some small maintenance tasks.
  + Updated translations.
- Drop pkgconfig(zeitgeist-2.0) BuildRequires: no longer needed.
- Drop the gedit-plugin-zeitgeist subpackage (obsoleted by the main
  package).
* Tue Feb  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Drop gedit-plugins-lang Requires: It should have been a
  Recommends, and those are not needed anymore as Supplements: are
  in place to take care of it.
* Thu Nov 21 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Re-add the synctex plugin.
  + Some small maintenance tasks.
  + Updated translations.
- Add new plugin sub package.
* Mon Sep  9 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Small fix.
  + Translation updates.
* Sat Sep  7 2019 luke@ljones.dev
- Update to version 3.33.92:
  + Small cleanup in top-level files.
  + Updated translations.
* Sat Aug 31 2019 mgorse@suse.com
- Update to version 3.33.90:
  + Switch from Autotools to Meson.
  + Add CI to test buildability and enforce Flake8.
  + Add new session saver plugin.
  + Remove synctex plugin.
  + Update Commander activation shortcut to Ctrl+.
  + Many more fixes.
- Switch to meson.
- Add session-saver package, and remove synctex package.
- Remove __pycache__ directory from files.
* Wed May 15 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2:
  + Fix ColorSchemer plugin for GTKSourceView 4.
  + Cache language names per session to prevent unnecessary web
    requests by Translate plugin.
  + Fix enabling and disabling the Translate plugin.
- Refresh bracketcompletion-use-key-release-event-to-work-wi.patch
  with quilt.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Tue Feb 19 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Fix GtkSourceView 4 Python imports.
  + Updated translations.
* Thu Jan 10 2019 bjorn.lie@gmail.com
- Update to version 3.31.4:
  + Switch from GTKSourceView 3 to GTKSourceView 4.
  + Stop using intltool.
  + Miscellaneous improvements.
  + Updated translations.
- Drop libtool BuildRequires, no longer needed.
- Replace pkgconfig(gtksourceview-3.0) with
  pkgconfig(gtksourceview-4) BuildRequires following upstream.
- Add libtool and pkgconfig(appstream-glib) BuildRequires: New
  dependencies.
- Drop gedit-plugin-dashboard sub-package and Obsolete it.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Terminal: fix change directory with vte >= 0.52.
  + Updated translations.
* Sun Sep  9 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + Updated translations.
* Mon Apr  9 2018 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + Updated translations.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + More fixes for the Translate plugin.
  + Updated translations.
* Wed Mar  7 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Fix the new Translate plugin.
  + Updated translations.
* Sun Mar  4 2018 luc14n0@linuxmail.org
- Update to version 3.27.1:
  + Introduce new Translate plugin.
  + Updated translations.
- Update URL tag to https://wiki.gnome.org/Apps/Gedit/PluginsLists,
  the current Gedit's plugins web subpage.
- Drop glib2_gsettings_schema_{post,postun,requires} macros: their
  functionality has been moved to RPM file triggers
  (RPM 4.13, suse_version >= 1330).
- Add:
  + gedit-plugins-translate subpackage.
  + gio-2.0, glib-2.0 and libpeas-1.0 pkgconfig and python3-base
    BuildRequires to avoid implicit dependencies.
- Simplify multiple fdupes calls to one against the prefix
  directory.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Sep  8 2017 jengelh@inai.de
- Update descriptions and RPM categories.
  Replace old RPM macros.
* Tue Aug 29 2017 dimstar@opensuse.org
- Fix patch tag line.
* Wed Mar  1 2017 hillwood@opensuse.org
- Add bracketcompletion-use-key-release-event-to-work-wi.patch:
  Switch to use key release event for ibus pinyin input method
  (bgo#778737, boo#1027448).
* Thu Sep 29 2016 jengelh@inai.de
- Use %%_smp_mflags for parallel build.
* Sun Sep 18 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Minor bugfixes.
  + Updated translations.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Stop passing V=1 to make, we do debugging locally.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Minor bugfixes, release the new stable version.
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + No changes, release the new stable version.
- Drop vte2 Requires from gedit-plugin-terminal: this plugin was
  ported to Vte-2.91 during the 3.14.0 cycle already.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.1:
  + Silence runtime warnings about gi.require_version in python.
  + Misc bugfixes.
  + Updated translations.
- Add vala BuildRequires: it's needed to build some plugins.
* Thu Apr 30 2015 dimstar@opensuse.org
- Update to version 3.17.0:
  + Add Find in Files plugin.
  + Misc bugfixes.
  + Updated translations.
- Add new (suggested) subpackage gedit-plugin-findinfiles.
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Misc bugfixes.
  + Updated translations.
* Mon Mar 23 2015 badshah400@gmail.com
- Main package should Suggest instead of Recommending individual
  plugin packages; split Provides for individual plugin
  subpackages to help with update.
* Tue Mar 17 2015 sfalken@opensuse.org
-  Reworked subpackages, to provide for individual installation of
  plugins, rather than getting all or nothing.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 3.15.1:
  + Misc bugfixes.
  + Updated translations.
* Wed Feb 18 2015 dimstar@opensuse.org
- Update to version 3.15.0:
  + Misc bugfixes.
  + Updated translations.
* Mon Feb  9 2015 zaitor@opensuse.org
- Move zeitgeist Requires to the gedit-plugin-zeitgeist
  sub-package, avoid dragging in zeitgeist for main package.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + Misc bugfixes.
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + New features and fixes:
  - Improve joinlines plugin.
  - Improve multiedit plugin.
  - Improve commander plugin.
  - Improve git plugin.
  - terminal: Port to vte-2.91.
  + Updated translations.
- Drop gedit-plugins-vte-2.91.patch: fixed upstream.
- Drop gnome-common BuildRequires and call to autogen.sh: no longer
  requires, as no patch touches the build system.
- Add typelib-1_0-Gucharmap-2_90 BuildRequires: new dependency. As
  the plugins are written in python, we only require the gi
  bindings, not the entire -devel package.
* Sat Jul 26 2014 dimstar@opensuse.org
- Update to version 3.13.2:
  + Adapt to the rename of gedit's desktop file.
* Tue Jul 22 2014 dimstar@opensuse.org
- Update to version 3.13.1:
  + Adapt the plugins for the changes in GeditDocument.
  + Various improvements and bug fixes.
  + Updated translations.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.0:
  + Moved zeitgeist plugin from gedit core to plugins.
  + Updated translations.
- Add pkgconfig(zeitgeist-2.0) BuildRequires.
- Create new subpackage gedit-plugin-zeitgeist (moved from gedit
  mainpackage, preserved the name of the package).
- Add gedit-plugins-vte-2.91.patch: Detect and use Vte 2.91.
- Add gnome-common BuildRequires and call to autogen.sh, as above
  patch touches the buildsystem.
- Replace pkgconfig(vte-2.90) BuildRequires with
  pkgconfig(vte-2.91).
* Mon Apr 14 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Split drawspaces into app/window/view activatables.
  + Fix bug preventing synctex to work.
  + Misc bugfixes.
  + Updated translations.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Ignore remote files in the git plugin.
  + Misc bugfixes.
  + Updated translations.
* Wed Mar  5 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Port synctex to new menu API.
  + Misc bugfixes.
  + Updated translations.
* Thu Feb  6 2014 dimstar@opensuse.org
- Update to version 3.11.2:
  + Port plugins to new menu API.
  + Misc bugfixes.
  + Updated translations.
* Wed Jan 15 2014 dimstar@opensuse.org
- Update to version 3.11.1:
  + Misc bugfixes.
  + Updated translations.
* Wed Dec  4 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Misc bugfixes.
  + Updated translations.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Misc bugfixes.
  + Updated translations.
* Sat Jul 20 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + Show the file's git status in the file browser.
  + Word completion: add configure options.
  + Misc bugfixes.
  + Updated translations.
- Add pkgconfig(libgit2-glib-1.0) BuildRequires: enable the git
  plugin.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + Add user help translations.
  + New git plugin.
  + terminal: handle drag and drop of files.
  + Follow gnome-terminal settings on terminal plugin.
  + Misc bugfixes.
  + Updated translations.
- Replace gnome-doc-utils-devel BuildRequires with yelp-tools,
  following upstreams port to the new documentation infrastructure.
* Sun May 26 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Follow gnome-terminal settings on terminal plugin.
  + Misc bugfixes.
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Port Dashboard to use libzeitgeist2.
  + New Color Schemer plugin.
  + Misc bugfixes.
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Misc bugfixes.
  + Updated translations.
* Tue Feb  5 2013 dimstar@opensuse.org
- Update to version 3.7.1:
  + Port plugins to python 3.
  + Drop session saver plugin.
  + Drop taglist plugin.
  + Misc bugfixes.
  + Updated translations.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Misc bugfixes.
  + Updated translations.
- Fix the fdupes calls: it's been a while gedit-2 did not exist
  anymore.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Use the textview instead of the overlay for the overlayed color
    button.
* Wed Sep 19 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Color picker now shows an overlayed color button when a
    hexadecimal color is selected
  + Misc bugfixes
  + Updated translations.
* Sun Aug 19 2012 dimstar@opensuse.org
- Update to version 3.5.1:
  + Misc bugfixes
  + Updated translations.
* Mon Apr 23 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Misc bugfixes
  + Updated translations.
- Drop gedit-plugins-implicit.patch: fixed upstream.
* Thu Mar  8 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Port colorpicker to new color chooser widget
  + Use GResource for drawspaces
  + Misc bugfixes
  + Updated translations.
* Sat Feb 25 2012 vuntz@opensuse.org
- Update to version 3.3.3:
  + Misc bugfixes
  + Updated translations.
- Remove sed hack in %%prep for broken configure check for vte:
  fixed upstream.
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 3.3.2:
  + Commander plugin bugfixes
  + Misc bugfixes
  + Updated translations.
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Add pkgconfig(vte-2.90) BuildRequires to keep building the
  terminal plugin, after a configure check got added for vte.
- Add a sed hack in %%prep to work around broken configure check for
  vte.
* Wed Dec 21 2011 vuntz@opensuse.org
- Add zeitgeist Requires for the dashboard plugin.
- Remove .la files: we're not interested in them.
- Explicitly list all plugins in the file list, so we notice if
  we're missing one.
* Sun Dec  4 2011 dimstar@opensuse.org
- Update to version 3.3.1:
  + New dashboard plugin
  + Misc bugfixes
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Add gedit-plugins-implicit.patch: Fix an implicit declaration of
  atoi(), as stdlib.h was not included.
- Change License tag to spdx identifier (GPL-2.0+).
* Mon Oct 17 2011 vuntz@opensuse.org
- Update to version 3.2.1:
  + i18n fixes
  + Fix doc module in commander plugin
  + Misc bugfixes
  + Updated translations.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
* Fri Sep 23 2011 andrea.turrini@gmail.com
- Fix typo in description.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 3.1.5:
  + Misc bugfixes
  + Updated translations.
* Tue Sep  6 2011 vuntz@opensuse.org
- Update to version 3.1.4:
  + Misc bugfixes
* Thu Sep  1 2011 vuntz@opensuse.org
- Update to version 3.1.3:
  + Misc bugfixes
  + Updated translations.
* Tue Jul  5 2011 vuntz@opensuse.org
- Update to version 3.1.2:
  + Misc bugfixes.
* Tue Jun 14 2011 dimstar@opensuse.org
- Update to version 3.1.1:
  + Misc bugfixes
  + Updated translations.
* Fri May 27 2011 dimstar@opensuse.org
- Update to version 3.0.3:
  + Misc bugfixes.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.2:
  + Misc bugfixes
  + Updated translations.
- Changes from version 3.0.1:
  + Misc bugfixes
* Wed Apr  6 2011 fcrozat@novell.com
- Update to version 3.0.0:
  - Port commander plugin to gtk+ 3.
* Tue Mar 29 2011 fcrozat@novell.com
- Update to version 2.91.3:
  + Update autoconf
  + Port bookmarks plugin to new message bus system
  + Update synctex to use the new dbus api
  + Misc Bugfixes
- Changes from version 2.91.2:
  + Misc bugfixes
- Changes from version 2.91.1:
  + Several plugins ported to gtk3/libpeas
  + Port charmap plugin to python.
  + Import the taglist plugin from gedit
  + Added new 'grep' commander module
  + Added synctex plugin
  + Misc Bugfixes
- Changes from version 2.90.0:
  + Ported textsize plugin to libpeas.
  + Update several plugins to new libpeas API.
- Move to pkgconfig()-style BuildRequires (including move to GNOME
  3 stack):
  + Old ones: gedit-devel, gtk2-devel, gtksourceview-devel.
  + New ones: gedit, gtk+-3.0, gtksourceview-3.0.
- Add pkgconfig() BuildRequires: dbus-python (for synctex plugin)
  and libpeas-gtk-1.0.
- Drop BuildRequires: gconf2-devel (move to GSettings), glib2-devel
  (implied by gtk3), gucharmap-devel, python-gtk-devel,
  python-gtksourceview-devel, vte-devel (move to libpeas-based
  plugins).
- Replace GConf2 schemas handling with GSettings schemas handling,
  with %%glib2_gsettings_schema_* macros.
* Mon Feb 21 2011 vuntz@opensuse.org
- Fix build, now that translation-update-upstream introduces the
  sr@latin translation. So we simply need to remove sr@Latn,
  instead of renaming it to sr@latin.
* Tue Sep 28 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Updated translations.
* Sat Sep 18 2010 vuntz@opensuse.org
- Update to version 2.31.7:
  + Misc fixes to synctex plugin.
- Changes from version 2.31.6:
  + Misc fixes to synctex plugin.
  + Misc fixes to commander and multiedit plugins.
  + Added new texsize plugin
  + Updated translations.
- Changes from version 2.31.5:
  + Added new synctex plugin.
- Changes from version 2.31.4 and earlier were discarded and will
  be in the 3.0 release.
* Fri Jun  4 2010 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Wed May 12 2010 dimstar@opensuse.org
- Choose valid RPM group.
* Thu Apr  1 2010 vuntz@opensuse.org
- Remove unneeded gedit BuildRequires, since gedit-devel now brings
  it in.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Commander:
  - change shortcut to control-+
  - hide commander when done
  - add autocomplete for edit.rename
  - make shell background and replace also accessible from the
    module
  - improve new-command template
  - implement support for accelerators
  - allow completion of empty command
  - various bug fixes
  + Add new align module
  + Updated translations.pdated translations.
* Sun Jan 17 2010 vuntz@opensuse.org
- Update to version 2.29.4:
  + Added new plugin commander
  + Added message bus bindings for bookmarks actions
  + Misc Bugfixes
  + Updated translations.
- Use fdupes on /usr/share/gedit-2 too.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update to version 2.29.3:
  + Misc Bugfixes
  + Updated translations.
- Changes from version 2.29.2:
  + Added multi edit plugin
  + Misc Bugfixes
  + Updated translations.
- Changes from version 2.29.1:
  + Added word completion plugin
  + Added support for drawing leading, text and trailing spaces
  + Misc Bugfixes
  + Updated translations.
* Thu Oct  1 2009 vuntz@opensuse.org
- Update to version 2.28.0:
  + Misc Bugfixes
  + Updated translations.
* Wed Aug 26 2009 vuntz@novell.com
- Update to version 2.27.1:
  + Remember bookmarks on files using metadata
  + Misc Bugfixes
  + Updated translations.
* Fri Jul 31 2009 vuntz@novell.com
- Update to version 2.26.3:
  + Misc bugfixes
  + Updated translations.
* Tue May 19 2009 dominique-obs@leuenberger.net
- Update to version 2.26.2:
  + Misc bugfixes
  + Updated translations.
* Mon May 18 2009 vuntz@novell.com
- Do not use tabs, remove trailing white spaces.
- Add missing Requires for the lang package.
- Fix the sr@Latn with a simple mv, instead of patching.
- Use fdupes.
- Add Requires on gedit.
* Sat May 16 2009 dominique-obs@leuenberger.net
- New package for gedit-plugins, all plugins enabled.
